##  Creating Fact Sheets from SAP Suggestions
You can create fact sheets from relevant SAP suggestions. If a corresponding fact sheet already exists, this option is not available.
To create a fact sheet from a suggestion, follow these steps:
  1. Select an SAP suggestion shown with the ![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio8794a2fcf1cf487aadb0e1ee8da90b05_LowRes.png) icon. This icon indicates that no fact sheet has been created from this suggestion.
  2. Choose Review and Add to Inventory.
  3. Add relations to business capabilities and applications, if applicable. You get suggestions for relevant relations.
  4. Choose Add to Inventory.


![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiof779a8b1c2c048198ffbc27c0edb2f4c_LowRes.png)
Creating a Fact Sheet from a Suggestion
